@@ -27,8 +27,8 @@ SPATIAL_RANGE_DELTA_LAT = 0.0001
 
 MAX_ADDRESS_LENGTH = 90  # 90 characters
 MAX_NOMINATIM_REQUESTS = 200
-NOMINATIM_BATCH_SIZE = 30
-NOMINATIM_MIN_SPLIT_BATCH_SIZE = 6  # Batches >=this are divided on failure
+NOMINATIM_BATCH_SIZE = 20
+NOMINATIM_MIN_SPLIT_BATCH_SIZE = 2  # Batches >=this are divided on failure
 
 LATITUDE = ('latitude', 'lat', 'ycoord', 'y_coord')
 LONGITUDE = ('longitude', 'long', 'lon', 'lng', 'xcoord', 'x_coord')
@@ -43,10 +43,10 @@ PROM_NOMINATIM_REQ_TIME = prometheus_client.Histogram(
 
 
 def get_spatial_ranges(values):
-    """
-    Retrieve the spatial ranges (i.e. bounding boxes) given the input gps points.
+    """Build a small number (3) of bounding boxes from lat/long points.
 
-    This performs K-Means clustering, returning a maximum of 3 ranges.
+    This performs K-Means clustering, returning a maximum of 3 clusters as
+    bounding boxes.
     """
 
     clustering = KMeans(n_clusters=min(N_RANGES, len(values)),
@@ -103,6 +103,14 @@ def get_spatial_ranges(values):
 
 
 def normalize_latlong_column_name(name, substrings):
+    """Find the remainder of the column name after removing a substring.
+
+    This goes over the substrings in order and removes the first it finds from
+    the name. You should therefore put the more specific substrings first and
+    the shorter ones last. For example, this is used to turn both
+    ``"cab_latitude_from"`` and ``"cab_longitude_from"`` into ``"cab__from"``
+    which can then be matched.
+    """
     name = name.strip().lower()
     for substr in substrings:
         idx = name.find(substr)
@@ -116,11 +124,15 @@ def normalize_latlong_column_name(name, substrings):
 class LatLongColumn(object):
     index: int
     name: str
-    values: list
     annot_pair: typing.Optional[str]
 
 
 def pair_latlong_columns(columns_lat, columns_long):
+    """Go through likely latitude and longitude columns and finds pairs.
+
+    This tries to find columns that match apart from latitude and longitude
+    keywords (e.g. `longitude`, `long`, `lon`).
+    """
     # Normalize latitude column names
     normalized_lat = {}
     for i, col in enumerate(columns_lat):
